// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/sensor_noise.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fsensor_5fnoise_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fsensor_5fnoise_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3013000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3013000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fsensor_5fnoise_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fsensor_5fnoise_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
extern IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fsensor_5fnoise_2eproto;
namespace ignition {
namespace msgs {
class SensorNoise;
class SensorNoiseDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SensorNoiseDefaultTypeInternal _SensorNoise_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SensorNoise* Arena::CreateMaybeMessage<::ignition::msgs::SensorNoise>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum SensorNoise_Type : int {
  SensorNoise_Type_NONE = 0,
  SensorNoise_Type_GAUSSIAN = 2,
  SensorNoise_Type_GAUSSIAN_QUANTIZED = 3,
  SensorNoise_Type_SensorNoise_Type_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  SensorNoise_Type_SensorNoise_Type_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool SensorNoise_Type_IsValid(int value);
constexpr SensorNoise_Type SensorNoise_Type_Type_MIN = SensorNoise_Type_NONE;
constexpr SensorNoise_Type SensorNoise_Type_Type_MAX = SensorNoise_Type_GAUSSIAN_QUANTIZED;
constexpr int SensorNoise_Type_Type_ARRAYSIZE = SensorNoise_Type_Type_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* SensorNoise_Type_descriptor();
template<typename T>
inline const std::string& SensorNoise_Type_Name(T enum_t_value) {
  static_assert(::std::is_same<T, SensorNoise_Type>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function SensorNoise_Type_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    SensorNoise_Type_descriptor(), enum_t_value);
}
inline bool SensorNoise_Type_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, SensorNoise_Type* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<SensorNoise_Type>(
    SensorNoise_Type_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE SensorNoise PROTOBUF_FINAL :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SensorNoise) */ {
 public:
  inline SensorNoise() : SensorNoise(nullptr) {}
  virtual ~SensorNoise();

  SensorNoise(const SensorNoise& from);
  SensorNoise(SensorNoise&& from) noexcept
    : SensorNoise() {
    *this = ::std::move(from);
  }

  inline SensorNoise& operator=(const SensorNoise& from) {
    CopyFrom(from);
    return *this;
  }
  inline SensorNoise& operator=(SensorNoise&& from) noexcept {
    if (GetArena() == from.GetArena()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return GetMetadataStatic().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return GetMetadataStatic().reflection;
  }
  static const SensorNoise& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const SensorNoise* internal_default_instance() {
    return reinterpret_cast<const SensorNoise*>(
               &_SensorNoise_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(SensorNoise& a, SensorNoise& b) {
    a.Swap(&b);
  }
  inline void Swap(SensorNoise* other) {
    if (other == this) return;
    if (GetArena() == other->GetArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SensorNoise* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SensorNoise* New() const final {
    return CreateMaybeMessage<SensorNoise>(nullptr);
  }

  SensorNoise* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SensorNoise>(arena);
  }
  void CopyFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void MergeFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void CopyFrom(const SensorNoise& from);
  void MergeFrom(const SensorNoise& from);
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  inline void SharedCtor();
  inline void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SensorNoise* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SensorNoise";
  }
  protected:
  explicit SensorNoise(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
  private:
  static ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadataStatic() {
    ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&::descriptor_table_ignition_2fmsgs_2fsensor_5fnoise_2eproto);
    return ::descriptor_table_ignition_2fmsgs_2fsensor_5fnoise_2eproto.file_level_metadata[kIndexInFileMessages];
  }

  public:

  // nested types ----------------------------------------------------

  typedef SensorNoise_Type Type;
  static constexpr Type NONE =
    SensorNoise_Type_NONE;
  static constexpr Type GAUSSIAN =
    SensorNoise_Type_GAUSSIAN;
  static constexpr Type GAUSSIAN_QUANTIZED =
    SensorNoise_Type_GAUSSIAN_QUANTIZED;
  static inline bool Type_IsValid(int value) {
    return SensorNoise_Type_IsValid(value);
  }
  static constexpr Type Type_MIN =
    SensorNoise_Type_Type_MIN;
  static constexpr Type Type_MAX =
    SensorNoise_Type_Type_MAX;
  static constexpr int Type_ARRAYSIZE =
    SensorNoise_Type_Type_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  Type_descriptor() {
    return SensorNoise_Type_descriptor();
  }
  template<typename T>
  static inline const std::string& Type_Name(T enum_t_value) {
    static_assert(::std::is_same<T, Type>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function Type_Name.");
    return SensorNoise_Type_Name(enum_t_value);
  }
  static inline bool Type_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      Type* value) {
    return SensorNoise_Type_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kHeaderFieldNumber = 1,
    kMeanFieldNumber = 3,
    kStddevFieldNumber = 4,
    kBiasMeanFieldNumber = 5,
    kBiasStddevFieldNumber = 6,
    kPrecisionFieldNumber = 7,
    kDynamicBiasStddevFieldNumber = 8,
    kDynamicBiasCorrelationTimeFieldNumber = 9,
    kTypeFieldNumber = 2,
  };
  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // double mean = 3;
  void clear_mean();
  double mean() const;
  void set_mean(double value);
  private:
  double _internal_mean() const;
  void _internal_set_mean(double value);
  public:

  // double stddev = 4;
  void clear_stddev();
  double stddev() const;
  void set_stddev(double value);
  private:
  double _internal_stddev() const;
  void _internal_set_stddev(double value);
  public:

  // double bias_mean = 5;
  void clear_bias_mean();
  double bias_mean() const;
  void set_bias_mean(double value);
  private:
  double _internal_bias_mean() const;
  void _internal_set_bias_mean(double value);
  public:

  // double bias_stddev = 6;
  void clear_bias_stddev();
  double bias_stddev() const;
  void set_bias_stddev(double value);
  private:
  double _internal_bias_stddev() const;
  void _internal_set_bias_stddev(double value);
  public:

  // double precision = 7;
  void clear_precision();
  double precision() const;
  void set_precision(double value);
  private:
  double _internal_precision() const;
  void _internal_set_precision(double value);
  public:

  // double dynamic_bias_stddev = 8;
  void clear_dynamic_bias_stddev();
  double dynamic_bias_stddev() const;
  void set_dynamic_bias_stddev(double value);
  private:
  double _internal_dynamic_bias_stddev() const;
  void _internal_set_dynamic_bias_stddev(double value);
  public:

  // double dynamic_bias_correlation_time = 9;
  void clear_dynamic_bias_correlation_time();
  double dynamic_bias_correlation_time() const;
  void set_dynamic_bias_correlation_time(double value);
  private:
  double _internal_dynamic_bias_correlation_time() const;
  void _internal_set_dynamic_bias_correlation_time(double value);
  public:

  // .ignition.msgs.SensorNoise.Type type = 2;
  void clear_type();
  ::ignition::msgs::SensorNoise_Type type() const;
  void set_type(::ignition::msgs::SensorNoise_Type value);
  private:
  ::ignition::msgs::SensorNoise_Type _internal_type() const;
  void _internal_set_type(::ignition::msgs::SensorNoise_Type value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.SensorNoise)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::Header* header_;
  double mean_;
  double stddev_;
  double bias_mean_;
  double bias_stddev_;
  double precision_;
  double dynamic_bias_stddev_;
  double dynamic_bias_correlation_time_;
  int type_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fsensor_5fnoise_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// SensorNoise

// .ignition.msgs.Header header = 1;
inline bool SensorNoise::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool SensorNoise::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& SensorNoise::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : *reinterpret_cast<const ::ignition::msgs::Header*>(
      &::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& SensorNoise::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SensorNoise.header)
  return _internal_header();
}
inline void SensorNoise::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SensorNoise.header)
}
inline ::ignition::msgs::Header* SensorNoise::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::ignition::msgs::Header* SensorNoise::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SensorNoise.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* SensorNoise::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArena());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* SensorNoise::mutable_header() {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SensorNoise.header)
  return _internal_mutable_header();
}
inline void SensorNoise::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header)->GetArena();
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SensorNoise.header)
}

// .ignition.msgs.SensorNoise.Type type = 2;
inline void SensorNoise::clear_type() {
  type_ = 0;
}
inline ::ignition::msgs::SensorNoise_Type SensorNoise::_internal_type() const {
  return static_cast< ::ignition::msgs::SensorNoise_Type >(type_);
}
inline ::ignition::msgs::SensorNoise_Type SensorNoise::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SensorNoise.type)
  return _internal_type();
}
inline void SensorNoise::_internal_set_type(::ignition::msgs::SensorNoise_Type value) {
  
  type_ = value;
}
inline void SensorNoise::set_type(::ignition::msgs::SensorNoise_Type value) {
  _internal_set_type(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SensorNoise.type)
}

// double mean = 3;
inline void SensorNoise::clear_mean() {
  mean_ = 0;
}
inline double SensorNoise::_internal_mean() const {
  return mean_;
}
inline double SensorNoise::mean() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SensorNoise.mean)
  return _internal_mean();
}
inline void SensorNoise::_internal_set_mean(double value) {
  
  mean_ = value;
}
inline void SensorNoise::set_mean(double value) {
  _internal_set_mean(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SensorNoise.mean)
}

// double stddev = 4;
inline void SensorNoise::clear_stddev() {
  stddev_ = 0;
}
inline double SensorNoise::_internal_stddev() const {
  return stddev_;
}
inline double SensorNoise::stddev() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SensorNoise.stddev)
  return _internal_stddev();
}
inline void SensorNoise::_internal_set_stddev(double value) {
  
  stddev_ = value;
}
inline void SensorNoise::set_stddev(double value) {
  _internal_set_stddev(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SensorNoise.stddev)
}

// double bias_mean = 5;
inline void SensorNoise::clear_bias_mean() {
  bias_mean_ = 0;
}
inline double SensorNoise::_internal_bias_mean() const {
  return bias_mean_;
}
inline double SensorNoise::bias_mean() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SensorNoise.bias_mean)
  return _internal_bias_mean();
}
inline void SensorNoise::_internal_set_bias_mean(double value) {
  
  bias_mean_ = value;
}
inline void SensorNoise::set_bias_mean(double value) {
  _internal_set_bias_mean(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SensorNoise.bias_mean)
}

// double bias_stddev = 6;
inline void SensorNoise::clear_bias_stddev() {
  bias_stddev_ = 0;
}
inline double SensorNoise::_internal_bias_stddev() const {
  return bias_stddev_;
}
inline double SensorNoise::bias_stddev() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SensorNoise.bias_stddev)
  return _internal_bias_stddev();
}
inline void SensorNoise::_internal_set_bias_stddev(double value) {
  
  bias_stddev_ = value;
}
inline void SensorNoise::set_bias_stddev(double value) {
  _internal_set_bias_stddev(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SensorNoise.bias_stddev)
}

// double precision = 7;
inline void SensorNoise::clear_precision() {
  precision_ = 0;
}
inline double SensorNoise::_internal_precision() const {
  return precision_;
}
inline double SensorNoise::precision() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SensorNoise.precision)
  return _internal_precision();
}
inline void SensorNoise::_internal_set_precision(double value) {
  
  precision_ = value;
}
inline void SensorNoise::set_precision(double value) {
  _internal_set_precision(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SensorNoise.precision)
}

// double dynamic_bias_stddev = 8;
inline void SensorNoise::clear_dynamic_bias_stddev() {
  dynamic_bias_stddev_ = 0;
}
inline double SensorNoise::_internal_dynamic_bias_stddev() const {
  return dynamic_bias_stddev_;
}
inline double SensorNoise::dynamic_bias_stddev() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SensorNoise.dynamic_bias_stddev)
  return _internal_dynamic_bias_stddev();
}
inline void SensorNoise::_internal_set_dynamic_bias_stddev(double value) {
  
  dynamic_bias_stddev_ = value;
}
inline void SensorNoise::set_dynamic_bias_stddev(double value) {
  _internal_set_dynamic_bias_stddev(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SensorNoise.dynamic_bias_stddev)
}

// double dynamic_bias_correlation_time = 9;
inline void SensorNoise::clear_dynamic_bias_correlation_time() {
  dynamic_bias_correlation_time_ = 0;
}
inline double SensorNoise::_internal_dynamic_bias_correlation_time() const {
  return dynamic_bias_correlation_time_;
}
inline double SensorNoise::dynamic_bias_correlation_time() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SensorNoise.dynamic_bias_correlation_time)
  return _internal_dynamic_bias_correlation_time();
}
inline void SensorNoise::_internal_set_dynamic_bias_correlation_time(double value) {
  
  dynamic_bias_correlation_time_ = value;
}
inline void SensorNoise::set_dynamic_bias_correlation_time(double value) {
  _internal_set_dynamic_bias_correlation_time(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SensorNoise.dynamic_bias_correlation_time)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<SensorNoise> SensorNoiseUniquePtr;
typedef std::unique_ptr<const SensorNoise> ConstSensorNoiseUniquePtr;
typedef std::shared_ptr<SensorNoise> SensorNoiseSharedPtr;
typedef std::shared_ptr<const SensorNoise> ConstSensorNoiseSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::SensorNoise_Type> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::SensorNoise_Type>() {
  return ::ignition::msgs::SensorNoise_Type_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fsensor_5fnoise_2eproto
