/*
 * Copyright (C) 2019 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "VersionRange";

/// \ingroup ignition.msgs
/// \interface VersionRange.
/// \brief Message that represents a range of versions, e.g. [1.4, 1.6].
/// If a min or max value is not present, then the interval is considered to
/// be unbounded in that direction.

import "ignition/msgs/version.proto";

message VersionRange
{
  /// \brief Min version.
  Version min = 1;

  /// \brief Max version.
  Version max = 2;
}
