# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/video_record.proto

require 'google/protobuf'

require 'ignition/msgs/header_pb'
Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/video_record.proto", :syntax => :proto3) do
    add_message "ignition.msgs.VideoRecord" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :start, :bool, 2
      optional :stop, :bool, 3
      optional :format, :string, 4
      optional :save_filename, :string, 5
    end
  end
end

module Ignition
  module Msgs
    VideoRecord = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.VideoRecord").msgclass
  end
end
