# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/cylindergeom.proto

require 'google/protobuf'

require 'ignition/msgs/header_pb'
Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/cylindergeom.proto", :syntax => :proto3) do
    add_message "ignition.msgs.CylinderGeom" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :radius, :double, 2
      optional :length, :double, 3
    end
  end
end

module Ignition
  module Msgs
    CylinderGeom = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.CylinderGeom").msgclass
  end
end
