// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/pose_trajectory.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpose_5ftrajectory_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpose_5ftrajectory_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3013000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3013000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/pose.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fpose_5ftrajectory_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fpose_5ftrajectory_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
extern IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fpose_5ftrajectory_2eproto;
namespace ignition {
namespace msgs {
class PoseTrajectory;
class PoseTrajectoryDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern PoseTrajectoryDefaultTypeInternal _PoseTrajectory_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::PoseTrajectory* Arena::CreateMaybeMessage<::ignition::msgs::PoseTrajectory>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE PoseTrajectory PROTOBUF_FINAL :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.PoseTrajectory) */ {
 public:
  inline PoseTrajectory() : PoseTrajectory(nullptr) {}
  virtual ~PoseTrajectory();

  PoseTrajectory(const PoseTrajectory& from);
  PoseTrajectory(PoseTrajectory&& from) noexcept
    : PoseTrajectory() {
    *this = ::std::move(from);
  }

  inline PoseTrajectory& operator=(const PoseTrajectory& from) {
    CopyFrom(from);
    return *this;
  }
  inline PoseTrajectory& operator=(PoseTrajectory&& from) noexcept {
    if (GetArena() == from.GetArena()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return GetMetadataStatic().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return GetMetadataStatic().reflection;
  }
  static const PoseTrajectory& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const PoseTrajectory* internal_default_instance() {
    return reinterpret_cast<const PoseTrajectory*>(
               &_PoseTrajectory_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(PoseTrajectory& a, PoseTrajectory& b) {
    a.Swap(&b);
  }
  inline void Swap(PoseTrajectory* other) {
    if (other == this) return;
    if (GetArena() == other->GetArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(PoseTrajectory* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline PoseTrajectory* New() const final {
    return CreateMaybeMessage<PoseTrajectory>(nullptr);
  }

  PoseTrajectory* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<PoseTrajectory>(arena);
  }
  void CopyFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void MergeFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void CopyFrom(const PoseTrajectory& from);
  void MergeFrom(const PoseTrajectory& from);
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  inline void SharedCtor();
  inline void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(PoseTrajectory* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.PoseTrajectory";
  }
  protected:
  explicit PoseTrajectory(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
  private:
  static ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadataStatic() {
    ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&::descriptor_table_ignition_2fmsgs_2fpose_5ftrajectory_2eproto);
    return ::descriptor_table_ignition_2fmsgs_2fpose_5ftrajectory_2eproto.file_level_metadata[kIndexInFileMessages];
  }

  public:

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kPoseFieldNumber = 3,
    kNameFieldNumber = 1,
    kIdFieldNumber = 2,
  };
  // repeated .ignition.msgs.Pose pose = 3;
  int pose_size() const;
  private:
  int _internal_pose_size() const;
  public:
  void clear_pose();
  ::ignition::msgs::Pose* mutable_pose(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose >*
      mutable_pose();
  private:
  const ::ignition::msgs::Pose& _internal_pose(int index) const;
  ::ignition::msgs::Pose* _internal_add_pose();
  public:
  const ::ignition::msgs::Pose& pose(int index) const;
  ::ignition::msgs::Pose* add_pose();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose >&
      pose() const;

  // string name = 1;
  void clear_name();
  const std::string& name() const;
  void set_name(const std::string& value);
  void set_name(std::string&& value);
  void set_name(const char* value);
  void set_name(const char* value, size_t size);
  std::string* mutable_name();
  std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // uint32 id = 2;
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.PoseTrajectory)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose > pose_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::PROTOBUF_NAMESPACE_ID::uint32 id_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fpose_5ftrajectory_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// PoseTrajectory

// string name = 1;
inline void PoseTrajectory::clear_name() {
  name_.ClearToEmpty(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline const std::string& PoseTrajectory::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PoseTrajectory.name)
  return _internal_name();
}
inline void PoseTrajectory::set_name(const std::string& value) {
  _internal_set_name(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PoseTrajectory.name)
}
inline std::string* PoseTrajectory::mutable_name() {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PoseTrajectory.name)
  return _internal_mutable_name();
}
inline const std::string& PoseTrajectory::_internal_name() const {
  return name_.Get();
}
inline void PoseTrajectory::_internal_set_name(const std::string& value) {
  
  name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), value, GetArena());
}
inline void PoseTrajectory::set_name(std::string&& value) {
  
  name_.Set(
    &::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::move(value), GetArena());
  // @@protoc_insertion_point(field_set_rvalue:ignition.msgs.PoseTrajectory.name)
}
inline void PoseTrajectory::set_name(const char* value) {
  GOOGLE_DCHECK(value != nullptr);
  
  name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(value),
              GetArena());
  // @@protoc_insertion_point(field_set_char:ignition.msgs.PoseTrajectory.name)
}
inline void PoseTrajectory::set_name(const char* value,
    size_t size) {
  
  name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(
      reinterpret_cast<const char*>(value), size), GetArena());
  // @@protoc_insertion_point(field_set_pointer:ignition.msgs.PoseTrajectory.name)
}
inline std::string* PoseTrajectory::_internal_mutable_name() {
  
  return name_.Mutable(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline std::string* PoseTrajectory::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PoseTrajectory.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline void PoseTrajectory::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArena());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PoseTrajectory.name)
}

// uint32 id = 2;
inline void PoseTrajectory::clear_id() {
  id_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PoseTrajectory::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PoseTrajectory::id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PoseTrajectory.id)
  return _internal_id();
}
inline void PoseTrajectory::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  id_ = value;
}
inline void PoseTrajectory::set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PoseTrajectory.id)
}

// repeated .ignition.msgs.Pose pose = 3;
inline int PoseTrajectory::_internal_pose_size() const {
  return pose_.size();
}
inline int PoseTrajectory::pose_size() const {
  return _internal_pose_size();
}
inline ::ignition::msgs::Pose* PoseTrajectory::mutable_pose(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PoseTrajectory.pose)
  return pose_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose >*
PoseTrajectory::mutable_pose() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.PoseTrajectory.pose)
  return &pose_;
}
inline const ::ignition::msgs::Pose& PoseTrajectory::_internal_pose(int index) const {
  return pose_.Get(index);
}
inline const ::ignition::msgs::Pose& PoseTrajectory::pose(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PoseTrajectory.pose)
  return _internal_pose(index);
}
inline ::ignition::msgs::Pose* PoseTrajectory::_internal_add_pose() {
  return pose_.Add();
}
inline ::ignition::msgs::Pose* PoseTrajectory::add_pose() {
  // @@protoc_insertion_point(field_add:ignition.msgs.PoseTrajectory.pose)
  return _internal_add_pose();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose >&
PoseTrajectory::pose() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.PoseTrajectory.pose)
  return pose_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<PoseTrajectory> PoseTrajectoryUniquePtr;
typedef std::unique_ptr<const PoseTrajectory> ConstPoseTrajectoryUniquePtr;
typedef std::shared_ptr<PoseTrajectory> PoseTrajectorySharedPtr;
typedef std::shared_ptr<const PoseTrajectory> ConstPoseTrajectorySharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpose_5ftrajectory_2eproto
