// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/raysensor.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fraysensor_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fraysensor_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3013000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3013000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fraysensor_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fraysensor_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
extern IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fraysensor_2eproto;
namespace ignition {
namespace msgs {
class RaySensor;
class RaySensorDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern RaySensorDefaultTypeInternal _RaySensor_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::RaySensor* Arena::CreateMaybeMessage<::ignition::msgs::RaySensor>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE RaySensor PROTOBUF_FINAL :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.RaySensor) */ {
 public:
  inline RaySensor() : RaySensor(nullptr) {}
  virtual ~RaySensor();

  RaySensor(const RaySensor& from);
  RaySensor(RaySensor&& from) noexcept
    : RaySensor() {
    *this = ::std::move(from);
  }

  inline RaySensor& operator=(const RaySensor& from) {
    CopyFrom(from);
    return *this;
  }
  inline RaySensor& operator=(RaySensor&& from) noexcept {
    if (GetArena() == from.GetArena()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return GetMetadataStatic().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return GetMetadataStatic().reflection;
  }
  static const RaySensor& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const RaySensor* internal_default_instance() {
    return reinterpret_cast<const RaySensor*>(
               &_RaySensor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(RaySensor& a, RaySensor& b) {
    a.Swap(&b);
  }
  inline void Swap(RaySensor* other) {
    if (other == this) return;
    if (GetArena() == other->GetArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(RaySensor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline RaySensor* New() const final {
    return CreateMaybeMessage<RaySensor>(nullptr);
  }

  RaySensor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<RaySensor>(arena);
  }
  void CopyFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void MergeFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void CopyFrom(const RaySensor& from);
  void MergeFrom(const RaySensor& from);
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  inline void SharedCtor();
  inline void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(RaySensor* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.RaySensor";
  }
  protected:
  explicit RaySensor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
  private:
  static ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadataStatic() {
    ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&::descriptor_table_ignition_2fmsgs_2fraysensor_2eproto);
    return ::descriptor_table_ignition_2fmsgs_2fraysensor_2eproto.file_level_metadata[kIndexInFileMessages];
  }

  public:

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kHeaderFieldNumber = 1,
    kDisplayScanFieldNumber = 2,
    kHorizontalSamplesFieldNumber = 3,
    kHorizontalResolutionFieldNumber = 4,
    kHorizontalMinAngleFieldNumber = 5,
    kHorizontalMaxAngleFieldNumber = 6,
    kVerticalResolutionFieldNumber = 8,
    kVerticalMinAngleFieldNumber = 9,
    kVerticalMaxAngleFieldNumber = 10,
    kRangeMinFieldNumber = 11,
    kRangeMaxFieldNumber = 12,
    kRangeResolutionFieldNumber = 13,
    kVerticalSamplesFieldNumber = 7,
  };
  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // bool display_scan = 2;
  void clear_display_scan();
  bool display_scan() const;
  void set_display_scan(bool value);
  private:
  bool _internal_display_scan() const;
  void _internal_set_display_scan(bool value);
  public:

  // int32 horizontal_samples = 3;
  void clear_horizontal_samples();
  ::PROTOBUF_NAMESPACE_ID::int32 horizontal_samples() const;
  void set_horizontal_samples(::PROTOBUF_NAMESPACE_ID::int32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::int32 _internal_horizontal_samples() const;
  void _internal_set_horizontal_samples(::PROTOBUF_NAMESPACE_ID::int32 value);
  public:

  // double horizontal_resolution = 4;
  void clear_horizontal_resolution();
  double horizontal_resolution() const;
  void set_horizontal_resolution(double value);
  private:
  double _internal_horizontal_resolution() const;
  void _internal_set_horizontal_resolution(double value);
  public:

  // double horizontal_min_angle = 5;
  void clear_horizontal_min_angle();
  double horizontal_min_angle() const;
  void set_horizontal_min_angle(double value);
  private:
  double _internal_horizontal_min_angle() const;
  void _internal_set_horizontal_min_angle(double value);
  public:

  // double horizontal_max_angle = 6;
  void clear_horizontal_max_angle();
  double horizontal_max_angle() const;
  void set_horizontal_max_angle(double value);
  private:
  double _internal_horizontal_max_angle() const;
  void _internal_set_horizontal_max_angle(double value);
  public:

  // double vertical_resolution = 8;
  void clear_vertical_resolution();
  double vertical_resolution() const;
  void set_vertical_resolution(double value);
  private:
  double _internal_vertical_resolution() const;
  void _internal_set_vertical_resolution(double value);
  public:

  // double vertical_min_angle = 9;
  void clear_vertical_min_angle();
  double vertical_min_angle() const;
  void set_vertical_min_angle(double value);
  private:
  double _internal_vertical_min_angle() const;
  void _internal_set_vertical_min_angle(double value);
  public:

  // double vertical_max_angle = 10;
  void clear_vertical_max_angle();
  double vertical_max_angle() const;
  void set_vertical_max_angle(double value);
  private:
  double _internal_vertical_max_angle() const;
  void _internal_set_vertical_max_angle(double value);
  public:

  // double range_min = 11;
  void clear_range_min();
  double range_min() const;
  void set_range_min(double value);
  private:
  double _internal_range_min() const;
  void _internal_set_range_min(double value);
  public:

  // double range_max = 12;
  void clear_range_max();
  double range_max() const;
  void set_range_max(double value);
  private:
  double _internal_range_max() const;
  void _internal_set_range_max(double value);
  public:

  // double range_resolution = 13;
  void clear_range_resolution();
  double range_resolution() const;
  void set_range_resolution(double value);
  private:
  double _internal_range_resolution() const;
  void _internal_set_range_resolution(double value);
  public:

  // int32 vertical_samples = 7;
  void clear_vertical_samples();
  ::PROTOBUF_NAMESPACE_ID::int32 vertical_samples() const;
  void set_vertical_samples(::PROTOBUF_NAMESPACE_ID::int32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::int32 _internal_vertical_samples() const;
  void _internal_set_vertical_samples(::PROTOBUF_NAMESPACE_ID::int32 value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.RaySensor)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::Header* header_;
  bool display_scan_;
  ::PROTOBUF_NAMESPACE_ID::int32 horizontal_samples_;
  double horizontal_resolution_;
  double horizontal_min_angle_;
  double horizontal_max_angle_;
  double vertical_resolution_;
  double vertical_min_angle_;
  double vertical_max_angle_;
  double range_min_;
  double range_max_;
  double range_resolution_;
  ::PROTOBUF_NAMESPACE_ID::int32 vertical_samples_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fraysensor_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// RaySensor

// .ignition.msgs.Header header = 1;
inline bool RaySensor::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool RaySensor::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& RaySensor::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : *reinterpret_cast<const ::ignition::msgs::Header*>(
      &::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& RaySensor::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.header)
  return _internal_header();
}
inline void RaySensor::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.RaySensor.header)
}
inline ::ignition::msgs::Header* RaySensor::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::ignition::msgs::Header* RaySensor::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.RaySensor.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* RaySensor::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArena());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* RaySensor::mutable_header() {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.RaySensor.header)
  return _internal_mutable_header();
}
inline void RaySensor::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header)->GetArena();
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.RaySensor.header)
}

// bool display_scan = 2;
inline void RaySensor::clear_display_scan() {
  display_scan_ = false;
}
inline bool RaySensor::_internal_display_scan() const {
  return display_scan_;
}
inline bool RaySensor::display_scan() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.display_scan)
  return _internal_display_scan();
}
inline void RaySensor::_internal_set_display_scan(bool value) {
  
  display_scan_ = value;
}
inline void RaySensor::set_display_scan(bool value) {
  _internal_set_display_scan(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.display_scan)
}

// int32 horizontal_samples = 3;
inline void RaySensor::clear_horizontal_samples() {
  horizontal_samples_ = 0;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 RaySensor::_internal_horizontal_samples() const {
  return horizontal_samples_;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 RaySensor::horizontal_samples() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.horizontal_samples)
  return _internal_horizontal_samples();
}
inline void RaySensor::_internal_set_horizontal_samples(::PROTOBUF_NAMESPACE_ID::int32 value) {
  
  horizontal_samples_ = value;
}
inline void RaySensor::set_horizontal_samples(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _internal_set_horizontal_samples(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.horizontal_samples)
}

// double horizontal_resolution = 4;
inline void RaySensor::clear_horizontal_resolution() {
  horizontal_resolution_ = 0;
}
inline double RaySensor::_internal_horizontal_resolution() const {
  return horizontal_resolution_;
}
inline double RaySensor::horizontal_resolution() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.horizontal_resolution)
  return _internal_horizontal_resolution();
}
inline void RaySensor::_internal_set_horizontal_resolution(double value) {
  
  horizontal_resolution_ = value;
}
inline void RaySensor::set_horizontal_resolution(double value) {
  _internal_set_horizontal_resolution(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.horizontal_resolution)
}

// double horizontal_min_angle = 5;
inline void RaySensor::clear_horizontal_min_angle() {
  horizontal_min_angle_ = 0;
}
inline double RaySensor::_internal_horizontal_min_angle() const {
  return horizontal_min_angle_;
}
inline double RaySensor::horizontal_min_angle() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.horizontal_min_angle)
  return _internal_horizontal_min_angle();
}
inline void RaySensor::_internal_set_horizontal_min_angle(double value) {
  
  horizontal_min_angle_ = value;
}
inline void RaySensor::set_horizontal_min_angle(double value) {
  _internal_set_horizontal_min_angle(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.horizontal_min_angle)
}

// double horizontal_max_angle = 6;
inline void RaySensor::clear_horizontal_max_angle() {
  horizontal_max_angle_ = 0;
}
inline double RaySensor::_internal_horizontal_max_angle() const {
  return horizontal_max_angle_;
}
inline double RaySensor::horizontal_max_angle() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.horizontal_max_angle)
  return _internal_horizontal_max_angle();
}
inline void RaySensor::_internal_set_horizontal_max_angle(double value) {
  
  horizontal_max_angle_ = value;
}
inline void RaySensor::set_horizontal_max_angle(double value) {
  _internal_set_horizontal_max_angle(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.horizontal_max_angle)
}

// int32 vertical_samples = 7;
inline void RaySensor::clear_vertical_samples() {
  vertical_samples_ = 0;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 RaySensor::_internal_vertical_samples() const {
  return vertical_samples_;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 RaySensor::vertical_samples() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.vertical_samples)
  return _internal_vertical_samples();
}
inline void RaySensor::_internal_set_vertical_samples(::PROTOBUF_NAMESPACE_ID::int32 value) {
  
  vertical_samples_ = value;
}
inline void RaySensor::set_vertical_samples(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _internal_set_vertical_samples(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.vertical_samples)
}

// double vertical_resolution = 8;
inline void RaySensor::clear_vertical_resolution() {
  vertical_resolution_ = 0;
}
inline double RaySensor::_internal_vertical_resolution() const {
  return vertical_resolution_;
}
inline double RaySensor::vertical_resolution() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.vertical_resolution)
  return _internal_vertical_resolution();
}
inline void RaySensor::_internal_set_vertical_resolution(double value) {
  
  vertical_resolution_ = value;
}
inline void RaySensor::set_vertical_resolution(double value) {
  _internal_set_vertical_resolution(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.vertical_resolution)
}

// double vertical_min_angle = 9;
inline void RaySensor::clear_vertical_min_angle() {
  vertical_min_angle_ = 0;
}
inline double RaySensor::_internal_vertical_min_angle() const {
  return vertical_min_angle_;
}
inline double RaySensor::vertical_min_angle() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.vertical_min_angle)
  return _internal_vertical_min_angle();
}
inline void RaySensor::_internal_set_vertical_min_angle(double value) {
  
  vertical_min_angle_ = value;
}
inline void RaySensor::set_vertical_min_angle(double value) {
  _internal_set_vertical_min_angle(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.vertical_min_angle)
}

// double vertical_max_angle = 10;
inline void RaySensor::clear_vertical_max_angle() {
  vertical_max_angle_ = 0;
}
inline double RaySensor::_internal_vertical_max_angle() const {
  return vertical_max_angle_;
}
inline double RaySensor::vertical_max_angle() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.vertical_max_angle)
  return _internal_vertical_max_angle();
}
inline void RaySensor::_internal_set_vertical_max_angle(double value) {
  
  vertical_max_angle_ = value;
}
inline void RaySensor::set_vertical_max_angle(double value) {
  _internal_set_vertical_max_angle(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.vertical_max_angle)
}

// double range_min = 11;
inline void RaySensor::clear_range_min() {
  range_min_ = 0;
}
inline double RaySensor::_internal_range_min() const {
  return range_min_;
}
inline double RaySensor::range_min() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.range_min)
  return _internal_range_min();
}
inline void RaySensor::_internal_set_range_min(double value) {
  
  range_min_ = value;
}
inline void RaySensor::set_range_min(double value) {
  _internal_set_range_min(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.range_min)
}

// double range_max = 12;
inline void RaySensor::clear_range_max() {
  range_max_ = 0;
}
inline double RaySensor::_internal_range_max() const {
  return range_max_;
}
inline double RaySensor::range_max() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.range_max)
  return _internal_range_max();
}
inline void RaySensor::_internal_set_range_max(double value) {
  
  range_max_ = value;
}
inline void RaySensor::set_range_max(double value) {
  _internal_set_range_max(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.range_max)
}

// double range_resolution = 13;
inline void RaySensor::clear_range_resolution() {
  range_resolution_ = 0;
}
inline double RaySensor::_internal_range_resolution() const {
  return range_resolution_;
}
inline double RaySensor::range_resolution() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.RaySensor.range_resolution)
  return _internal_range_resolution();
}
inline void RaySensor::_internal_set_range_resolution(double value) {
  
  range_resolution_ = value;
}
inline void RaySensor::set_range_resolution(double value) {
  _internal_set_range_resolution(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.RaySensor.range_resolution)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<RaySensor> RaySensorUniquePtr;
typedef std::unique_ptr<const RaySensor> ConstRaySensorUniquePtr;
typedef std::shared_ptr<RaySensor> RaySensorSharedPtr;
typedef std::shared_ptr<const RaySensor> ConstRaySensorSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fraysensor_2eproto
