# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/log_control.proto

require 'google/protobuf'

require 'ignition/msgs/header_pb'
Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/log_control.proto", :syntax => :proto3) do
    add_message "ignition.msgs.LogControl" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :start, :bool, 2
      optional :stop, :bool, 3
      optional :paused, :bool, 4
      optional :base_path, :string, 5
      optional :encoding, :string, 6
      optional :record_resources, :string, 7
    end
  end
end

module Ignition
  module Msgs
    LogControl = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.LogControl").msgclass
  end
end
