# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/int32.proto

require 'google/protobuf'

require 'ignition/msgs/header_pb'
Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/int32.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Int32" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :data, :int32, 2
    end
  end
end

module Ignition
  module Msgs
    Int32 = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Int32").msgclass
  end
end
