// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/link.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2flink_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2flink_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3013000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3013000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/inlined_string_field.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/inertial.pb.h"
#include "ignition/msgs/collision.pb.h"
#include "ignition/msgs/visual.pb.h"
#include "ignition/msgs/light.pb.h"
#include "ignition/msgs/sensor.pb.h"
#include "ignition/msgs/projector.pb.h"
#include "ignition/msgs/pose.pb.h"
#include "ignition/msgs/battery.pb.h"
#include "ignition/msgs/density.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2flink_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2flink_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
extern IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2flink_2eproto;
namespace ignition {
namespace msgs {
class Link;
class LinkDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern LinkDefaultTypeInternal _Link_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Link* Arena::CreateMaybeMessage<::ignition::msgs::Link>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE Link PROTOBUF_FINAL :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Link) */ {
 public:
  inline Link() : Link(nullptr) {}
  virtual ~Link();

  Link(const Link& from);
  Link(Link&& from) noexcept
    : Link() {
    *this = ::std::move(from);
  }

  inline Link& operator=(const Link& from) {
    CopyFrom(from);
    return *this;
  }
  inline Link& operator=(Link&& from) noexcept {
    if (GetArena() == from.GetArena()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return GetMetadataStatic().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return GetMetadataStatic().reflection;
  }
  static const Link& default_instance();

  static void InitAsDefaultInstance();  // FOR INTERNAL USE ONLY
  static inline const Link* internal_default_instance() {
    return reinterpret_cast<const Link*>(
               &_Link_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Link& a, Link& b) {
    a.Swap(&b);
  }
  inline void Swap(Link* other) {
    if (other == this) return;
    if (GetArena() == other->GetArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Link* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Link* New() const final {
    return CreateMaybeMessage<Link>(nullptr);
  }

  Link* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Link>(arena);
  }
  void CopyFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void MergeFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void CopyFrom(const Link& from);
  void MergeFrom(const Link& from);
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  inline void SharedCtor();
  inline void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Link* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Link";
  }
  protected:
  explicit Link(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
  private:
  static ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadataStatic() {
    ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&::descriptor_table_ignition_2fmsgs_2flink_2eproto);
    return ::descriptor_table_ignition_2fmsgs_2flink_2eproto.file_level_metadata[kIndexInFileMessages];
  }

  public:

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kVisualFieldNumber = 11,
    kCollisionFieldNumber = 12,
    kSensorFieldNumber = 13,
    kProjectorFieldNumber = 14,
    kBatteryFieldNumber = 16,
    kLightFieldNumber = 17,
    kNameFieldNumber = 3,
    kHeaderFieldNumber = 1,
    kDensityFieldNumber = 8,
    kInertialFieldNumber = 9,
    kPoseFieldNumber = 10,
    kIdFieldNumber = 2,
    kSelfCollideFieldNumber = 4,
    kGravityFieldNumber = 5,
    kKinematicFieldNumber = 6,
    kEnabledFieldNumber = 7,
    kCanonicalFieldNumber = 15,
  };
  // repeated .ignition.msgs.Visual visual = 11;
  int visual_size() const;
  private:
  int _internal_visual_size() const;
  public:
  void clear_visual();
  ::ignition::msgs::Visual* mutable_visual(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual >*
      mutable_visual();
  private:
  const ::ignition::msgs::Visual& _internal_visual(int index) const;
  ::ignition::msgs::Visual* _internal_add_visual();
  public:
  const ::ignition::msgs::Visual& visual(int index) const;
  ::ignition::msgs::Visual* add_visual();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual >&
      visual() const;

  // repeated .ignition.msgs.Collision collision = 12;
  int collision_size() const;
  private:
  int _internal_collision_size() const;
  public:
  void clear_collision();
  ::ignition::msgs::Collision* mutable_collision(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Collision >*
      mutable_collision();
  private:
  const ::ignition::msgs::Collision& _internal_collision(int index) const;
  ::ignition::msgs::Collision* _internal_add_collision();
  public:
  const ::ignition::msgs::Collision& collision(int index) const;
  ::ignition::msgs::Collision* add_collision();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Collision >&
      collision() const;

  // repeated .ignition.msgs.Sensor sensor = 13;
  int sensor_size() const;
  private:
  int _internal_sensor_size() const;
  public:
  void clear_sensor();
  ::ignition::msgs::Sensor* mutable_sensor(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Sensor >*
      mutable_sensor();
  private:
  const ::ignition::msgs::Sensor& _internal_sensor(int index) const;
  ::ignition::msgs::Sensor* _internal_add_sensor();
  public:
  const ::ignition::msgs::Sensor& sensor(int index) const;
  ::ignition::msgs::Sensor* add_sensor();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Sensor >&
      sensor() const;

  // repeated .ignition.msgs.Projector projector = 14;
  int projector_size() const;
  private:
  int _internal_projector_size() const;
  public:
  void clear_projector();
  ::ignition::msgs::Projector* mutable_projector(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Projector >*
      mutable_projector();
  private:
  const ::ignition::msgs::Projector& _internal_projector(int index) const;
  ::ignition::msgs::Projector* _internal_add_projector();
  public:
  const ::ignition::msgs::Projector& projector(int index) const;
  ::ignition::msgs::Projector* add_projector();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Projector >&
      projector() const;

  // repeated .ignition.msgs.Battery battery = 16;
  int battery_size() const;
  private:
  int _internal_battery_size() const;
  public:
  void clear_battery();
  ::ignition::msgs::Battery* mutable_battery(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Battery >*
      mutable_battery();
  private:
  const ::ignition::msgs::Battery& _internal_battery(int index) const;
  ::ignition::msgs::Battery* _internal_add_battery();
  public:
  const ::ignition::msgs::Battery& battery(int index) const;
  ::ignition::msgs::Battery* add_battery();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Battery >&
      battery() const;

  // repeated .ignition.msgs.Light light = 17;
  int light_size() const;
  private:
  int _internal_light_size() const;
  public:
  void clear_light();
  ::ignition::msgs::Light* mutable_light(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light >*
      mutable_light();
  private:
  const ::ignition::msgs::Light& _internal_light(int index) const;
  ::ignition::msgs::Light* _internal_add_light();
  public:
  const ::ignition::msgs::Light& light(int index) const;
  ::ignition::msgs::Light* add_light();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light >&
      light() const;

  // string name = 3;
  void clear_name();
  const std::string& name() const;
  void set_name(const std::string& value);
  void set_name(std::string&& value);
  void set_name(const char* value);
  void set_name(const char* value, size_t size);
  std::string* mutable_name();
  std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Density density = 8;
  bool has_density() const;
  private:
  bool _internal_has_density() const;
  public:
  void clear_density();
  const ::ignition::msgs::Density& density() const;
  ::ignition::msgs::Density* release_density();
  ::ignition::msgs::Density* mutable_density();
  void set_allocated_density(::ignition::msgs::Density* density);
  private:
  const ::ignition::msgs::Density& _internal_density() const;
  ::ignition::msgs::Density* _internal_mutable_density();
  public:
  void unsafe_arena_set_allocated_density(
      ::ignition::msgs::Density* density);
  ::ignition::msgs::Density* unsafe_arena_release_density();

  // .ignition.msgs.Inertial inertial = 9;
  bool has_inertial() const;
  private:
  bool _internal_has_inertial() const;
  public:
  void clear_inertial();
  const ::ignition::msgs::Inertial& inertial() const;
  ::ignition::msgs::Inertial* release_inertial();
  ::ignition::msgs::Inertial* mutable_inertial();
  void set_allocated_inertial(::ignition::msgs::Inertial* inertial);
  private:
  const ::ignition::msgs::Inertial& _internal_inertial() const;
  ::ignition::msgs::Inertial* _internal_mutable_inertial();
  public:
  void unsafe_arena_set_allocated_inertial(
      ::ignition::msgs::Inertial* inertial);
  ::ignition::msgs::Inertial* unsafe_arena_release_inertial();

  // .ignition.msgs.Pose pose = 10;
  bool has_pose() const;
  private:
  bool _internal_has_pose() const;
  public:
  void clear_pose();
  const ::ignition::msgs::Pose& pose() const;
  ::ignition::msgs::Pose* release_pose();
  ::ignition::msgs::Pose* mutable_pose();
  void set_allocated_pose(::ignition::msgs::Pose* pose);
  private:
  const ::ignition::msgs::Pose& _internal_pose() const;
  ::ignition::msgs::Pose* _internal_mutable_pose();
  public:
  void unsafe_arena_set_allocated_pose(
      ::ignition::msgs::Pose* pose);
  ::ignition::msgs::Pose* unsafe_arena_release_pose();

  // uint32 id = 2;
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // bool self_collide = 4;
  void clear_self_collide();
  bool self_collide() const;
  void set_self_collide(bool value);
  private:
  bool _internal_self_collide() const;
  void _internal_set_self_collide(bool value);
  public:

  // bool gravity = 5;
  void clear_gravity();
  bool gravity() const;
  void set_gravity(bool value);
  private:
  bool _internal_gravity() const;
  void _internal_set_gravity(bool value);
  public:

  // bool kinematic = 6;
  void clear_kinematic();
  bool kinematic() const;
  void set_kinematic(bool value);
  private:
  bool _internal_kinematic() const;
  void _internal_set_kinematic(bool value);
  public:

  // bool enabled = 7;
  void clear_enabled();
  bool enabled() const;
  void set_enabled(bool value);
  private:
  bool _internal_enabled() const;
  void _internal_set_enabled(bool value);
  public:

  // bool canonical = 15;
  void clear_canonical();
  bool canonical() const;
  void set_canonical(bool value);
  private:
  bool _internal_canonical() const;
  void _internal_set_canonical(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Link)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual > visual_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Collision > collision_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Sensor > sensor_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Projector > projector_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Battery > battery_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light > light_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Density* density_;
  ::ignition::msgs::Inertial* inertial_;
  ::ignition::msgs::Pose* pose_;
  ::PROTOBUF_NAMESPACE_ID::uint32 id_;
  bool self_collide_;
  bool gravity_;
  bool kinematic_;
  bool enabled_;
  bool canonical_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2flink_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Link

// .ignition.msgs.Header header = 1;
inline bool Link::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Link::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Link::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : *reinterpret_cast<const ::ignition::msgs::Header*>(
      &::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Link::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.header)
  return _internal_header();
}
inline void Link::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Link.header)
}
inline ::ignition::msgs::Header* Link::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::ignition::msgs::Header* Link::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Link.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Link::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArena());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Link::mutable_header() {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.header)
  return _internal_mutable_header();
}
inline void Link::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header)->GetArena();
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Link.header)
}

// uint32 id = 2;
inline void Link::clear_id() {
  id_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Link::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Link::id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.id)
  return _internal_id();
}
inline void Link::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  id_ = value;
}
inline void Link::set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Link.id)
}

// string name = 3;
inline void Link::clear_name() {
  name_.ClearToEmpty(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline const std::string& Link::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.name)
  return _internal_name();
}
inline void Link::set_name(const std::string& value) {
  _internal_set_name(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Link.name)
}
inline std::string* Link::mutable_name() {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.name)
  return _internal_mutable_name();
}
inline const std::string& Link::_internal_name() const {
  return name_.Get();
}
inline void Link::_internal_set_name(const std::string& value) {
  
  name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), value, GetArena());
}
inline void Link::set_name(std::string&& value) {
  
  name_.Set(
    &::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::move(value), GetArena());
  // @@protoc_insertion_point(field_set_rvalue:ignition.msgs.Link.name)
}
inline void Link::set_name(const char* value) {
  GOOGLE_DCHECK(value != nullptr);
  
  name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(value),
              GetArena());
  // @@protoc_insertion_point(field_set_char:ignition.msgs.Link.name)
}
inline void Link::set_name(const char* value,
    size_t size) {
  
  name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ::std::string(
      reinterpret_cast<const char*>(value), size), GetArena());
  // @@protoc_insertion_point(field_set_pointer:ignition.msgs.Link.name)
}
inline std::string* Link::_internal_mutable_name() {
  
  return name_.Mutable(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline std::string* Link::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Link.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline void Link::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArena());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Link.name)
}

// bool self_collide = 4;
inline void Link::clear_self_collide() {
  self_collide_ = false;
}
inline bool Link::_internal_self_collide() const {
  return self_collide_;
}
inline bool Link::self_collide() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.self_collide)
  return _internal_self_collide();
}
inline void Link::_internal_set_self_collide(bool value) {
  
  self_collide_ = value;
}
inline void Link::set_self_collide(bool value) {
  _internal_set_self_collide(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Link.self_collide)
}

// bool gravity = 5;
inline void Link::clear_gravity() {
  gravity_ = false;
}
inline bool Link::_internal_gravity() const {
  return gravity_;
}
inline bool Link::gravity() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.gravity)
  return _internal_gravity();
}
inline void Link::_internal_set_gravity(bool value) {
  
  gravity_ = value;
}
inline void Link::set_gravity(bool value) {
  _internal_set_gravity(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Link.gravity)
}

// bool kinematic = 6;
inline void Link::clear_kinematic() {
  kinematic_ = false;
}
inline bool Link::_internal_kinematic() const {
  return kinematic_;
}
inline bool Link::kinematic() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.kinematic)
  return _internal_kinematic();
}
inline void Link::_internal_set_kinematic(bool value) {
  
  kinematic_ = value;
}
inline void Link::set_kinematic(bool value) {
  _internal_set_kinematic(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Link.kinematic)
}

// bool enabled = 7;
inline void Link::clear_enabled() {
  enabled_ = false;
}
inline bool Link::_internal_enabled() const {
  return enabled_;
}
inline bool Link::enabled() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.enabled)
  return _internal_enabled();
}
inline void Link::_internal_set_enabled(bool value) {
  
  enabled_ = value;
}
inline void Link::set_enabled(bool value) {
  _internal_set_enabled(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Link.enabled)
}

// .ignition.msgs.Density density = 8;
inline bool Link::_internal_has_density() const {
  return this != internal_default_instance() && density_ != nullptr;
}
inline bool Link::has_density() const {
  return _internal_has_density();
}
inline const ::ignition::msgs::Density& Link::_internal_density() const {
  const ::ignition::msgs::Density* p = density_;
  return p != nullptr ? *p : *reinterpret_cast<const ::ignition::msgs::Density*>(
      &::ignition::msgs::_Density_default_instance_);
}
inline const ::ignition::msgs::Density& Link::density() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.density)
  return _internal_density();
}
inline void Link::unsafe_arena_set_allocated_density(
    ::ignition::msgs::Density* density) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(density_);
  }
  density_ = density;
  if (density) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Link.density)
}
inline ::ignition::msgs::Density* Link::release_density() {
  
  ::ignition::msgs::Density* temp = density_;
  density_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::ignition::msgs::Density* Link::unsafe_arena_release_density() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Link.density)
  
  ::ignition::msgs::Density* temp = density_;
  density_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Density* Link::_internal_mutable_density() {
  
  if (density_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Density>(GetArena());
    density_ = p;
  }
  return density_;
}
inline ::ignition::msgs::Density* Link::mutable_density() {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.density)
  return _internal_mutable_density();
}
inline void Link::set_allocated_density(::ignition::msgs::Density* density) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(density_);
  }
  if (density) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(density)->GetArena();
    if (message_arena != submessage_arena) {
      density = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, density, submessage_arena);
    }
    
  } else {
    
  }
  density_ = density;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Link.density)
}

// .ignition.msgs.Inertial inertial = 9;
inline bool Link::_internal_has_inertial() const {
  return this != internal_default_instance() && inertial_ != nullptr;
}
inline bool Link::has_inertial() const {
  return _internal_has_inertial();
}
inline const ::ignition::msgs::Inertial& Link::_internal_inertial() const {
  const ::ignition::msgs::Inertial* p = inertial_;
  return p != nullptr ? *p : *reinterpret_cast<const ::ignition::msgs::Inertial*>(
      &::ignition::msgs::_Inertial_default_instance_);
}
inline const ::ignition::msgs::Inertial& Link::inertial() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.inertial)
  return _internal_inertial();
}
inline void Link::unsafe_arena_set_allocated_inertial(
    ::ignition::msgs::Inertial* inertial) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(inertial_);
  }
  inertial_ = inertial;
  if (inertial) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Link.inertial)
}
inline ::ignition::msgs::Inertial* Link::release_inertial() {
  
  ::ignition::msgs::Inertial* temp = inertial_;
  inertial_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::ignition::msgs::Inertial* Link::unsafe_arena_release_inertial() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Link.inertial)
  
  ::ignition::msgs::Inertial* temp = inertial_;
  inertial_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Inertial* Link::_internal_mutable_inertial() {
  
  if (inertial_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Inertial>(GetArena());
    inertial_ = p;
  }
  return inertial_;
}
inline ::ignition::msgs::Inertial* Link::mutable_inertial() {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.inertial)
  return _internal_mutable_inertial();
}
inline void Link::set_allocated_inertial(::ignition::msgs::Inertial* inertial) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(inertial_);
  }
  if (inertial) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(inertial)->GetArena();
    if (message_arena != submessage_arena) {
      inertial = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, inertial, submessage_arena);
    }
    
  } else {
    
  }
  inertial_ = inertial;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Link.inertial)
}

// .ignition.msgs.Pose pose = 10;
inline bool Link::_internal_has_pose() const {
  return this != internal_default_instance() && pose_ != nullptr;
}
inline bool Link::has_pose() const {
  return _internal_has_pose();
}
inline const ::ignition::msgs::Pose& Link::_internal_pose() const {
  const ::ignition::msgs::Pose* p = pose_;
  return p != nullptr ? *p : *reinterpret_cast<const ::ignition::msgs::Pose*>(
      &::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& Link::pose() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.pose)
  return _internal_pose();
}
inline void Link::unsafe_arena_set_allocated_pose(
    ::ignition::msgs::Pose* pose) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  pose_ = pose;
  if (pose) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Link.pose)
}
inline ::ignition::msgs::Pose* Link::release_pose() {
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::ignition::msgs::Pose* Link::unsafe_arena_release_pose() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Link.pose)
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Pose* Link::_internal_mutable_pose() {
  
  if (pose_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Pose>(GetArena());
    pose_ = p;
  }
  return pose_;
}
inline ::ignition::msgs::Pose* Link::mutable_pose() {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.pose)
  return _internal_mutable_pose();
}
inline void Link::set_allocated_pose(::ignition::msgs::Pose* pose) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  if (pose) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose)->GetArena();
    if (message_arena != submessage_arena) {
      pose = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pose, submessage_arena);
    }
    
  } else {
    
  }
  pose_ = pose;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Link.pose)
}

// repeated .ignition.msgs.Visual visual = 11;
inline int Link::_internal_visual_size() const {
  return visual_.size();
}
inline int Link::visual_size() const {
  return _internal_visual_size();
}
inline ::ignition::msgs::Visual* Link::mutable_visual(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.visual)
  return visual_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual >*
Link::mutable_visual() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Link.visual)
  return &visual_;
}
inline const ::ignition::msgs::Visual& Link::_internal_visual(int index) const {
  return visual_.Get(index);
}
inline const ::ignition::msgs::Visual& Link::visual(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.visual)
  return _internal_visual(index);
}
inline ::ignition::msgs::Visual* Link::_internal_add_visual() {
  return visual_.Add();
}
inline ::ignition::msgs::Visual* Link::add_visual() {
  // @@protoc_insertion_point(field_add:ignition.msgs.Link.visual)
  return _internal_add_visual();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual >&
Link::visual() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Link.visual)
  return visual_;
}

// repeated .ignition.msgs.Collision collision = 12;
inline int Link::_internal_collision_size() const {
  return collision_.size();
}
inline int Link::collision_size() const {
  return _internal_collision_size();
}
inline ::ignition::msgs::Collision* Link::mutable_collision(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.collision)
  return collision_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Collision >*
Link::mutable_collision() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Link.collision)
  return &collision_;
}
inline const ::ignition::msgs::Collision& Link::_internal_collision(int index) const {
  return collision_.Get(index);
}
inline const ::ignition::msgs::Collision& Link::collision(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.collision)
  return _internal_collision(index);
}
inline ::ignition::msgs::Collision* Link::_internal_add_collision() {
  return collision_.Add();
}
inline ::ignition::msgs::Collision* Link::add_collision() {
  // @@protoc_insertion_point(field_add:ignition.msgs.Link.collision)
  return _internal_add_collision();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Collision >&
Link::collision() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Link.collision)
  return collision_;
}

// repeated .ignition.msgs.Sensor sensor = 13;
inline int Link::_internal_sensor_size() const {
  return sensor_.size();
}
inline int Link::sensor_size() const {
  return _internal_sensor_size();
}
inline ::ignition::msgs::Sensor* Link::mutable_sensor(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.sensor)
  return sensor_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Sensor >*
Link::mutable_sensor() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Link.sensor)
  return &sensor_;
}
inline const ::ignition::msgs::Sensor& Link::_internal_sensor(int index) const {
  return sensor_.Get(index);
}
inline const ::ignition::msgs::Sensor& Link::sensor(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.sensor)
  return _internal_sensor(index);
}
inline ::ignition::msgs::Sensor* Link::_internal_add_sensor() {
  return sensor_.Add();
}
inline ::ignition::msgs::Sensor* Link::add_sensor() {
  // @@protoc_insertion_point(field_add:ignition.msgs.Link.sensor)
  return _internal_add_sensor();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Sensor >&
Link::sensor() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Link.sensor)
  return sensor_;
}

// repeated .ignition.msgs.Projector projector = 14;
inline int Link::_internal_projector_size() const {
  return projector_.size();
}
inline int Link::projector_size() const {
  return _internal_projector_size();
}
inline ::ignition::msgs::Projector* Link::mutable_projector(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.projector)
  return projector_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Projector >*
Link::mutable_projector() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Link.projector)
  return &projector_;
}
inline const ::ignition::msgs::Projector& Link::_internal_projector(int index) const {
  return projector_.Get(index);
}
inline const ::ignition::msgs::Projector& Link::projector(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.projector)
  return _internal_projector(index);
}
inline ::ignition::msgs::Projector* Link::_internal_add_projector() {
  return projector_.Add();
}
inline ::ignition::msgs::Projector* Link::add_projector() {
  // @@protoc_insertion_point(field_add:ignition.msgs.Link.projector)
  return _internal_add_projector();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Projector >&
Link::projector() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Link.projector)
  return projector_;
}

// bool canonical = 15;
inline void Link::clear_canonical() {
  canonical_ = false;
}
inline bool Link::_internal_canonical() const {
  return canonical_;
}
inline bool Link::canonical() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.canonical)
  return _internal_canonical();
}
inline void Link::_internal_set_canonical(bool value) {
  
  canonical_ = value;
}
inline void Link::set_canonical(bool value) {
  _internal_set_canonical(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Link.canonical)
}

// repeated .ignition.msgs.Battery battery = 16;
inline int Link::_internal_battery_size() const {
  return battery_.size();
}
inline int Link::battery_size() const {
  return _internal_battery_size();
}
inline ::ignition::msgs::Battery* Link::mutable_battery(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.battery)
  return battery_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Battery >*
Link::mutable_battery() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Link.battery)
  return &battery_;
}
inline const ::ignition::msgs::Battery& Link::_internal_battery(int index) const {
  return battery_.Get(index);
}
inline const ::ignition::msgs::Battery& Link::battery(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.battery)
  return _internal_battery(index);
}
inline ::ignition::msgs::Battery* Link::_internal_add_battery() {
  return battery_.Add();
}
inline ::ignition::msgs::Battery* Link::add_battery() {
  // @@protoc_insertion_point(field_add:ignition.msgs.Link.battery)
  return _internal_add_battery();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Battery >&
Link::battery() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Link.battery)
  return battery_;
}

// repeated .ignition.msgs.Light light = 17;
inline int Link::_internal_light_size() const {
  return light_.size();
}
inline int Link::light_size() const {
  return _internal_light_size();
}
inline ::ignition::msgs::Light* Link::mutable_light(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Link.light)
  return light_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light >*
Link::mutable_light() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Link.light)
  return &light_;
}
inline const ::ignition::msgs::Light& Link::_internal_light(int index) const {
  return light_.Get(index);
}
inline const ::ignition::msgs::Light& Link::light(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Link.light)
  return _internal_light(index);
}
inline ::ignition::msgs::Light* Link::_internal_add_light() {
  return light_.Add();
}
inline ::ignition::msgs::Light* Link::add_light() {
  // @@protoc_insertion_point(field_add:ignition.msgs.Link.light)
  return _internal_add_light();
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light >&
Link::light() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Link.light)
  return light_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Link> LinkUniquePtr;
typedef std::unique_ptr<const Link> ConstLinkUniquePtr;
typedef std::shared_ptr<Link> LinkSharedPtr;
typedef std::shared_ptr<const Link> ConstLinkSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2flink_2eproto
