# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/imagegeom.proto

require 'google/protobuf'

require 'ignition/msgs/header_pb'
Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/imagegeom.proto", :syntax => :proto3) do
    add_message "ignition.msgs.ImageGeom" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :uri, :string, 2
      optional :scale, :double, 3
      optional :threshold, :int32, 4
      optional :height, :double, 5
      optional :granularity, :int32, 6
    end
  end
end

module Ignition
  module Msgs
    ImageGeom = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.ImageGeom").msgclass
  end
end
